@@ -119,13 +119,26 @@ ServerPrivate::~ServerPrivate()
 //////////////////////////////////////////////////
 void ServerPrivate::OnSignal(int _sig)
 {
-  gzdbg << "Server received signal[" << _sig  << "]\n";
-  this->Stop();
+  // There's a good chance that objects are being destructed from the previous
+  // signal, so it's not safe to call Stop if we've done it already.
+  if (!this->signalReceived)
+  {
+    this->signalReceived = true;
+    gzdbg << "Server received signal[" << _sig  << "]\n";
+    this->Stop();
+  }
 }
 
 /////////////////////////////////////////////////
 void ServerPrivate::Stop()
 {
+  // Stop might be called from the signal handler thread (new in Ionic) instead
+  // of the main thread, so we need to ensure that we keep `ServerPrivate` alive
+  // while the signal handler is still active. We do that by synchronizing on
+  // the `runMutex` here in ServerPrivate::Run right after the call
+  // SimulationRunner::Run returns. That way, `ServerPrivate::Run` cannot return
+  // before the signal handler is finished.
+  std::lock_guard<std::mutex> lock(this->runMutex);
   this->running = false;
   for (std::unique_ptr<SimulationRunner> &runner : this->simRunners)
   {
@@ -137,6 +150,13 @@ void ServerPrivate::Stop()
 bool ServerPrivate::Run(const uint64_t _iterations,
     std::optional<std::condition_variable *> _cond)
 {
+  // Return early if we've received a signal right before.
+  // The ServerPrivate signal handler would set `running=false`,
+  // but we immediately would set it to true here, which will essentially ignore
+  // the signal. Since we can't reliably use the `running` variable, we return
+  // if `signalReceived` is true
+  if (this->signalReceived)
+    return false;
   this->runMutex.lock();
   this->running = true;
   if (_cond)
@@ -198,6 +218,8 @@ bool ServerPrivate::Run(const uint64_t _iterations,
     result = this->workerPool->WaitForResults();
   }
 
+  // See comments ServerPrivate::Stop() for why we lock this mutex here.
+  std::lock_guard<std::mutex> lock(this->runMutex);
   this->running = false;
   return result;
 }
