@@ -20,6 +20,7 @@
 #include <algorithm>
 #include <memory>
 #include <ostream>
+#include <unordered_set>
 #ifdef HAVE_PYBIND11
 #include <pybind11/pybind11.h>
 #endif
@@ -39,6 +40,7 @@
 #include <vector>
 
 #include "gz/common/Profiler.hh"
+#include "gz/sim/Constants.hh"
 #include "gz/sim/components/Model.hh"
 #include "gz/sim/components/Name.hh"
 #include "gz/sim/components/Sensor.hh"
@@ -74,7 +76,7 @@ namespace {
 // 1. Gazebo is built without Pybind11
 // 2. The python interpreter is not initialized. This could happen in tests that
 //    create a SimulationRunner without sim::Server where the interpreter is
-//    intialized.
+//    initialized.
 // 3. sim::Server was instantiated by a Python module. In this case, there's a
 //    chance that this would be called with the GIL already released.
 struct MaybeGilScopedRelease
@@ -195,6 +197,14 @@ SimulationRunner::SimulationRunner(const sdf::World &_world,
 
   this->node = std::make_unique<transport::Node>(opts);
 
+  std::vector<transport::MessagePublisher> pubs;
+  std::vector<transport::MessagePublisher> subs;
+  this->node->TopicInfo("/world/" + this->worldName + "/stats", pubs, subs);
+  if (!pubs.empty())
+  {
+    gzerr << "Another world of the same name is running" << std::endl;
+  }
+
   // Create the system manager
   this->systemMgr = std::make_unique<SystemManager>(
       _systemLoader, &this->entityCompMgr, &this->eventMgr, validNs,
@@ -269,6 +279,18 @@ SimulationRunner::SimulationRunner(const sdf::World &_world,
   if (_world.Gui())
   {
     this->guiMsg = convert<msgs::GUI>(*_world.Gui());
+
+    auto worldElem = this->sdfWorld.Element();
+    if (worldElem)
+    {
+      auto policies = worldElem->FindElement("gz:policies");
+      if (policies)
+      {
+        auto headerData = this->guiMsg.mutable_header()->add_data();
+        headerData->set_key("gz:policies");
+        headerData->add_value(policies->ToString(""));
+      }
+    }
   }
 
   std::string infoService{"gui/info"};
@@ -657,7 +679,7 @@ void SimulationRunner::StopWorkerThreads()
 bool SimulationRunner::Run(const uint64_t _iterations)
 {
   // \todo(nkoenig) Systems will need a an update structure, such as
-  // priorties, or a dependency chain.
+  // priorities, or a dependency chain.
   //
   // \todo(nkoenig) We should implement the two-phase update detailed
   // in the design.
@@ -1590,24 +1612,65 @@ void SimulationRunner::CreateEntities(const sdf::World &_world)
   // Load any additional plugins from the Server Configuration
   this->LoadServerPlugins(this->serverConfig.Plugins());
 
+  auto loadedWorldPlugins = this->systemMgr->TotalByEntity(worldEntity);
   // If we have reached this point and no world systems have been loaded, then
   // load a default set of systems.
-  if (this->systemMgr->TotalByEntity(worldEntity).empty())
+
+  auto worldElem = this->sdfWorld.Element();
+  bool includeServerConfigPlugins = true;
+  if (worldElem)
   {
-    gzmsg << "No systems loaded from SDF, loading defaults" << std::endl;
-    bool isPlayback = !this->serverConfig.LogPlaybackPath().empty();
-    auto plugins = gz::sim::loadPluginInfo(isPlayback);
-    this->LoadServerPlugins(plugins);
+    auto policies = worldElem->FindElement(std::string(kPoliciesTag));
+    if (policies)
+    {
+      includeServerConfigPlugins =
+        policies
+        ->Get<bool>("include_server_config_plugins", includeServerConfigPlugins)
+        .first;
+    }
   }
-  // Load logging plugins after all server plugins so that necessary
-  // plugins such as SceneBroadcaster are loaded first. This might be
-  // a bug or an assumption made in the logging plugins.
-  this->LoadLoggingPlugins(this->serverConfig);
+
+  if (includeServerConfigPlugins || loadedWorldPlugins.empty())
+  {
+    bool isPlayback = !this->serverConfig.LogPlaybackPath().empty();
+    auto defaultPlugins = gz::sim::loadPluginInfo(isPlayback);
+    if (loadedWorldPlugins.empty())
+    {
+      gzmsg << "No systems loaded from SDF, loading defaults" << std::endl;
+    }
+    else
+    {
+      std::unordered_set<std::string> loadedWorldPluginFileNames;
+      for (const auto &pl : loadedWorldPlugins)
+      {
+        loadedWorldPluginFileNames.insert(pl.fname);
+      }
+      auto isPluginLoaded =
+          [&loadedWorldPluginFileNames](const ServerConfig::PluginInfo &_pl)
+      {
+          return loadedWorldPluginFileNames.count(_pl.Plugin().Filename()) != 0;
+      };
+
+      // Remove plugin if it's already loaded so as to not duplicate world
+      // plugins.
+      defaultPlugins.remove_if(isPluginLoaded);
+
+      gzdbg << "Additional plugins to load:\n";
+      for (const auto &plugin : defaultPlugins)
+      {
+        gzdbg << plugin.Plugin().Name() << " " << plugin.Plugin().Filename()
+              << "\n";
+      }
+    }
+
+    this->LoadServerPlugins(defaultPlugins);
+    // Load logging plugins after all server plugins so that necessary
+    // plugins such as SceneBroadcaster are loaded first. This might be
+    // a bug or an assumption made in the logging plugins.
+    this->LoadLoggingPlugins(this->serverConfig);
+
+  };
+
   // Store the initial state of the ECM;
   this->initialEntityCompMgr.CopyFrom(this->entityCompMgr);
-
-  // Publish empty GUI messages for worlds that have no GUI in the beginning.
-  // In the future, support modifying GUI from the server at runtime.
-  if (_world.Gui())
-    this->guiMsg = convert<msgs::GUI>(*_world.Gui());
 }
