@@ -1006,7 +1006,7 @@ TEST_F(UtilTest, ResolveSdfWorldFile)
   // resolved path will have extra world version information at the end.
   EXPECT_EQ(0u, resolvedPath.find(expectedPath));
 
-  // Now try to resolve the downloaded world file using an aboslute path
+  // Now try to resolve the downloaded world file using an absolute path
   EXPECT_EQ(resolvedPath, resolveSdfWorldFile(resolvedPath));
 
   // The "shapes.sdf" world file should resolve.
@@ -1136,3 +1136,12 @@ TEST_F(UtilTest, TransformAxisAlignedBoxFrame)
   aabExp = aabExp + transform.Pos();
   EXPECT_EQ(aabExp, transformAxisAlignedBox(aab, transform));
 }
+
+/////////////////////////////////////////////////
+TEST_F(UtilTest, StaticPlugin)
+{
+  EXPECT_FALSE(staticPluginPrefixStr().empty());
+  EXPECT_FALSE(isStaticPlugin("my_plugin"));
+  EXPECT_FALSE(isStaticPlugin(""));
+  EXPECT_TRUE(isStaticPlugin(staticPluginPrefixStr() + "my_plugin"));
+}
