@@ -308,7 +308,7 @@ void LogPlaybackPrivate::ReplaceResourceURIs(EntityComponentManager &_ecm)
   // Define equality functions for replacing component uri
   auto uriEqual = [&](const std::string &_s1, const std::string &_s2) -> bool
   {
-    return (_s1.compare(_s2) == 0);
+    return _s1 == _s2;
   };
 
   auto geoUriEqual = [&](const sdf::Geometry &_g1,
@@ -510,14 +510,6 @@ void LogPlayback::Update(const UpdateInfo &_info, EntityComponentManager &_ecm)
   {
     auto msgType = iter->Type();
 
-    // Support ignition.msgs for backwards compatibility. Remove on gz-sim9
-    std::string deprecatedPrefix{"ignition.msgs"};
-    auto pos = msgType.find(deprecatedPrefix);
-    if (pos != std::string::npos)
-    {
-      msgType.replace(pos, deprecatedPrefix.size(), "gz.msgs");
-    }
-
     if (msgType == "gz.msgs.SerializedState")
     {
       msgs::SerializedState msg;
