@@ -459,7 +459,7 @@ void MagnetometerPrivate::Update(
           auto latLonEle = sphericalCoordinates(_entity, _ecm);
           if (!latLonEle)
           {
-            gzwarn << "Failed to update Magnetometer sensor enity [" << _entity
+            gzwarn << "Failed to update Magnetometer sensor entity [" << _entity
                     << "]. Spherical coordinates not set." << std::endl;
             return true;
           }
