@@ -254,7 +254,7 @@ void PosePublisher::Configure(const Entity &_entity,
   this->dataPtr->usePoseV =
     _sdf->Get<bool>("use_pose_vector_msg", this->dataPtr->usePoseV).first;
 
-  std::string poseTopic = topicFromScopedName(_entity, _ecm, false) + "/pose";
+  std::string poseTopic = topicFromScopedName(_entity, _ecm, true) + "/pose";
   if (poseTopic.empty())
   {
     poseTopic = "/pose";
